@@ -123,6 +123,7 @@ struct Hjava_lang_Object *guarana_wrap(struct Hjava_lang_Class *clazz, jvalue va
   default:
     ABORT();
   }
+  return 0; /* never reached */
 }
 
 int guarana_unwrap(struct Hjava_lang_Class *clazz, jvalue *val, struct Hjava_lang_Object *wrapper) {
@@ -178,6 +179,7 @@ int guarana_unwrap(struct Hjava_lang_Class *clazz, jvalue *val, struct Hjava_lan
   default:
     ABORT();
   }
+  return 0; /* never reached */
 }
 
 NativeResult *guarana_handle_operation(NativeOperation *op) {
@@ -186,7 +188,7 @@ NativeResult *guarana_handle_operation(NativeOperation *op) {
   res = (NativeResult*)(do_execute_java_class_method("BR/unicamp/Guarana/Guarana", "perform", "(LBR/unicamp/Guarana/Operation;)LBR/unicamp/Guarana/Result;", op).l);
 
   if (res->kind & res_thrown)
-    throwException(res->res.j);
+    throwException(res->res.l);
 
   return res;
 }
@@ -200,7 +202,6 @@ guarana_slots_reify_method_invocation(struct Hjava_lang_Object *obj, Method *met
   if (mo) {
     NativeOperation *op;
     NativeResult *res;
-    jvalue *arg;
     char *sig;
     int argcount;
 
