@@ -44,6 +44,8 @@
 #include "support.h"
 #include "external.h"
 #include "baseClasses.h"
+#include "soft.h"
+#include "exception.h"
 #include "../../libraries/clib/native/Method.h"
 #include "../../libraries/clib/native/Constructor.h"
 #include "../../libraries/clib/native/Field.h"
