@@ -263,7 +263,11 @@ struct Hjava_lang_Object* BR_unicamp_Guarana_Guarana_makeProxy(struct Hjava_lang
       strcmp(CLASS_CNAME(clazz), "BR/unicamp/Guarana/Operation") == 0 ||
       strcmp(CLASS_CNAME(clazz), "BR/unicamp/Guarana/Result") == 0)
       return 0;
-  obj = newObjectNoMessage(clazz);
+  if (CLASS_IS_ARRAY(clazz)) {
+      obj = newArrayNoMessage(CLASS_ELEMENT_TYPE(clazz), 0);
+  } else {
+      obj = newObjectNoMessage(clazz);
+  }
   if (!newProxy)
       newProxy = lookupClass("BR/unicamp/Guarana/NewProxy");
   msg = execute_java_constructor(0, newProxy, "(Ljava/lang/Object;)V", obj);
