@@ -1,4 +1,4 @@
-// $Id: logMetaPerformance.java,v 1.1 1998/06/10 20:46:08 oliva Exp $
+// $Id: logMetaPerformance.java,v 1.2 1998/09/23 06:30:18 oliva Exp $
 
 /* Copyright 1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -24,12 +24,12 @@ import BR.unicamp.Guarana.MetaObject;
  * 
  *
  * @author Alexandre Oliva
- * @version $Revision: 1.1 $
+ * @version $Revision: 1.2 $
  */
 public class logMetaPerformance {
     public static void main(final String[] argv) {
 	Guarana.reconfigure(performance.statictest.class, null,
-			    new MetaLogger(System.err));
+			    new MetaLogger(System.out));
 	performance.main(argv);
     }
 }
