@@ -1,4 +1,4 @@
-// $Id: ModifyResult.java,v 1.3 1998/07/28 10:12:27 oliva Exp $
+// $Id: ModifyResult.java,v 1.4 1998/09/10 20:17:20 oliva Exp $
 
 /* Copyright 1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -27,7 +27,7 @@ import BR.unicamp.Guarana.*;
  * result.
  *
  * @author Alexandre Oliva
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
  */
 public class ModifyResult extends MetaObject {
     final static java.lang.reflect.Method hashCode, toString;
@@ -42,15 +42,15 @@ public class ModifyResult extends MetaObject {
     public Result handle(final Operation op, final Object ob) {
 	final java.lang.reflect.Method meth = op.getMethod();
 	if (hashCode.equals(meth))
-	    return Result.returnInt(0, op);
+	    return Result.returnInt(0, op); // make it return 0
 	if (toString.equals(meth))
-	    return Result.modifyResult;
-	return Result.noResult;
+	    return Result.modifyResult; // asks for permission to modify it
+	return Result.noResult; // not interested in the result
     }
     public Result handle(final Result res, final Object ob) {
 	Operation op = res.getOperation();
 	if (toString.equals(op.getMethod()))
-	    return Result.returnObject("modified "
+	    return Result.returnObject("modified " // replace result
 				       + res.getObjectValue(), op);
 	return null;
     }
