@@ -1,4 +1,4 @@
-// $Id: OperationFactoryInternal.java,v 1.8 1998/06/08 14:33:46 oliva Exp $
+// $Id: OperationFactoryInternal.java,v 1.9 1998/07/24 06:43:57 oliva Exp $
 
 /* Copyright 1997,1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -37,7 +37,7 @@ import java.lang.reflect.Field;
     @see Operation#validate
 
     @author Alexandre Oliva
-    @version $Revision: 1.8 $ */
+    @version $Revision: 1.9 $ */
 final class OperationFactoryInternal extends OperationFactory {
     static {
         System.loadLibrary("guarana");
@@ -77,7 +77,11 @@ final class OperationFactoryInternal extends OperationFactory {
 	@exception IllegalArgumentException if the Method return type
 	is not compatible with the expected type of the replaced
 	Operation, or if the replaced Operation was not intercepted
-	yet.  */
+	yet.
+
+	@exception IllegalArgumentException if the given Method does
+	not satisfy the exception propagation restrictions of the
+	replaced Operation.  */
     public native Operation invoke(final Method method,
 				   final Object[] arguments,
 				   final Operation operation)
@@ -97,7 +101,11 @@ final class OperationFactoryInternal extends OperationFactory {
 
 	@exception IllegalArgumentException if the expected type of
 	the replaced Operation is not void, or if the replaced
-	Operation was not intercepted yet.  */
+	Operation was not intercepted yet.
+
+	@exception IllegalArgumentException if the given Method does
+	not satisfy the exception propagation restrictions of the
+	replaced Operation.  */
     public native Operation construct(final Constructor constructor,
 				      final Object[] arguments,
 				      final Operation operation)
